@@ -4,15 +4,18 @@ from datetime import datetime, timedelta
 import pytz
 import times
 
-from .date import MutableDate, add_month, subtract_month
+from .date import MutableDate
 from .parse import parse_date_and_formula, parse_js_date
 
 
 class Moment(MutableDate):
     """A class to abstract date difficulties."""
 
-    def __init__(self, date=None, formula=None):
-        date, formula = parse_date_and_formula(date, formula)
+    def __init__(self, *args):
+        if args:
+            date, formula = parse_date_and_formula(*args)
+        else:
+            date, formula = (None, None)
         self._date = date
         self._formula = formula
 
@@ -90,6 +93,15 @@ class Moment(MutableDate):
         """Return a clone of the current moment."""
         return Moment(self._date)
 
+    def copy(self):
+        """Same as clone."""
+        return Moment(self._date)
+
+    @property
+    def date(self):
+        """Access the internal datetime variable."""
+        return self._date
+
     def __repr__(self):
         if self._date is not None:
             return "<Moment(%s)>" % (self._date.strftime(self._formula))
